==> vdcpy-0.0.10.tar.gz: vdcpy-0.0.10/vdcpy/link.py <==
import requests

import vdcpy.config as config


def get_links(
    link_id=None, name=None, created_by=None, format=None, visibility=None,
    work=None):
    """
    Get a list of links from the VDC API.

    Parameters
    ----------
    link_id : str
        The ID of the link to retrieve.
    name : str
        The name of the link to retrieve.
    created_by : str
        The email address of the user who created the link.
    format : str
        The format of the link to retrieve.
    visibility : str
        The visibility of the link to retrieve.
    work : str
        The ID of the work to which the link belongs.
    
    Returns
    -------
    link_list : list
        A list of links.
    """
    link_list = []
    query = f'{config.API_URL}/{config.LINK_NAMESPACE}'
    if link_id is not None:
        query += f'?id={link_id}'
    if name is not None:
        if link_id is None:
            query += f'?name={name}'
        else:
            query += f'&name={name}'
    if created_by is not None:
        if link_id is None and name is None:
            query += f'?created_by={created_by}'
        else:
            query += f'&created_by={created_by}'
    if format is not None:
        if link_id is None and name is None and created_by is None:
            query += f'?format={format}'
        else:
            query += f'&format={format}'
    if visibility is not None:
        if link_id is None and name is None and created_by is None \
            and format is None:
            query += f'?visibility={visibility}'
        else:
            query += f'&visibility={visibility}'
    if work is not None:
        if link_id is None and name is None and created_by is None \
            and format is None and visibility is None:
            query += f'?work={work}'
        else:
            query += f'&work={work}'
    response = requests.get(query)
    if response.status_code == 200:
        link_list = response.json()
    else:
        raise Exception(f'Error getting projects: {response.status_code}')
    return link_list


def delete_link(link_id):
    """
    Delete a link from the VDC API.

    Parameters
    ----------
    link_id : str
        The ID of the link to delete.

    Returns
    -------
    True if the link was deleted. Otherwise it rise an exception.
    """
    query = f'{config.API_URL}/{config.LINK_NAMESPACE}/{link_id}'
    response = requests.delete(query)
    if response.status_code == 204:
        return True
    else:
        raise Exception(f'Error deleting link: {response.status_code}')


def add_link(link_info):
    """
    Add a link to the VDC API.
    """
    query = f'{config.API_URL}/{config.LINK_NAMESPACE}'
    response = requests.post(query, json=link_info)
    if response.status_code == 201:
        return response.json()
    else:
        raise Exception(
            f'Error adding work: {response.status_code} - {response.json()}'
        )


def update_link(link_id, link_info):
    """
    Update a link in the VDC API.
    """
    query = f'{config.API_URL}/{config.LINK_NAMESPACE}/{link_id}'
    response = requests.put(query, json=link_info)

    if response.status_code == 200:
        return response.json()
    else:
        raise Exception(
            f'Error updating link: {response.status_code} - {response.json()}'
        )

def download_link(link_id, file_path):
    """
    Download the file from the link.

    Parameters
    ----------
    link_id : str
        The ID of the file to download.
    file_path : str
        The path to which the file should be downloaded.
    
    Returns
    -------
    file_path : str
        The path to which the file was downloaded.
    """
    query = f'{config.API_URL}/{config.LINK_NAMESPACE}?id={link_id}'
    response = requests.get(query)
    if response.status_code == 200 and response.json():
        link_url = response.json()[0]['link']
        if link_url is not None:
            # Download the file into the file_path
            response = requests.get(link_url)
            if response.status_code == 200:
                with open(file_path, 'wb') as file:
                    file.write(response.content)
                return file_path
            else:
                raise Exception(
                    f'Error downloading link: {response.status_code}')
    else:
        raise Exception(
            f'Error getting link information: {response.status_code}')

==> vdcpy-0.0.11.tar.gz: vdcpy-0.0.11/vdcpy/link.py <==
import requests

import vdcpy.config as config


def get_links(
    link_id=None, name=None, created_by=None, format=None, visibility=None,
    work=None):
    """
    Get a list of links from the VDC API.

    Parameters
    ----------
    link_id : str
        The ID of the link to retrieve.
    name : str
        The name of the link to retrieve.
    created_by : str
        The email address of the user who created the link.
    format : str
        The format of the link to retrieve.
    visibility : str
        The visibility of the link to retrieve.
    work : str
        The ID of the work to which the link belongs.
    
    Returns
    -------
    link_list : list
        A list of links.
    """
    link_list = []
    query = f'{config.API_URL}/{config.LINK_NAMESPACE}'
    if link_id is not None:
        query += f'?id={link_id}'
    if name is not None:
        if link_id is None:
            query += f'?name={name}'
        else:
            query += f'&name={name}'
    if created_by is not None:
        if link_id is None and name is None:
            query += f'?created_by={created_by}'
        else:
            query += f'&created_by={created_by}'
    if format is not None:
        if link_id is None and name is None and created_by is None:
            query += f'?format={format}'
        else:
            query += f'&format={format}'
    if visibility is not None:
        if link_id is None and name is None and created_by is None \
            and format is None:
            query += f'?visibility={visibility}'
        else:
            query += f'&visibility={visibility}'
    if work is not None:
        if link_id is None and name is None and created_by is None \
            and format is None and visibility is None:
            query += f'?work={work}'
        else:
            query += f'&work={work}'
    response = requests.get(query)
    if response.status_code == 200:
        link_list = response.json()
    else:
        raise Exception(f'Error getting projects: {response.status_code}')
    return link_list


def delete_link(link_id, auth_token=None):
    """
    Delete a link from the VDC API.

    Parameters
    ----------
    link_id : str
        The ID of the link to delete.
    auth_token : str
        The authentication token to use for the request.

    Returns
    -------
    True if the link was deleted. Otherwise it rise an exception.
    """
    query = f'{config.API_URL}/{config.LINK_NAMESPACE}/{link_id}'
    if auth_token is not None:
        headers = {'Authorization': auth_token}
    else:
        headers = None
    response = requests.delete(query, headers=headers)
    if response.status_code == 204:
        return True
    else:
        raise Exception(f'Error deleting link: {response.status_code}')


def add_link(link_info, auth_token=None):
    """
    Add a link to the VDC API.

    Parameters
    ----------
    link_info : dict
        A dictionary containing the information about the link to add.
    auth_token : str
        The authentication token to use for the request.
    """
    query = f'{config.API_URL}/{config.LINK_NAMESPACE}'
    if auth_token is not None:
        headers = {'Authorization': auth_token}
    else:
        headers = None
    response = requests.post(query, json=link_info, headers=headers)
    if response.status_code == 201:
        return response.json()
    else:
        raise Exception(
            f'Error adding work: {response.status_code} - {response.json()}'
        )


def update_link(link_id, link_info, auth_token=None):
    """
    Update a link in the VDC API.

    Parameters
    ----------
    link_id : str
        The ID of the link to update.
    link_info : dict
        A dictionary containing the information about the link to update.
    auth_token : str
        The authentication token to use for the request.

    Returns
    -------
    The updated link information.
    """
    query = f'{config.API_URL}/{config.LINK_NAMESPACE}/{link_id}'
    if auth_token is not None:
        headers = {'Authorization': auth_token}
    else:
        headers = None
    response = requests.put(query, json=link_info, headers=headers)

    if response.status_code == 200:
        return response.json()
    else:
        raise Exception(
            f'Error updating link: {response.status_code} - {response.json()}'
        )


def download_link(link_id, file_path):
    """
    Download the file from the link.

    Parameters
    ----------
    link_id : str
        The ID of the file to download.
    file_path : str
        The path to which the file should be downloaded.
    
    Returns
    -------
    file_path : str
        The path to which the file was downloaded.
    """
    query = f'{config.API_URL}/{config.LINK_NAMESPACE}?id={link_id}'
    response = requests.get(query)
    if response.status_code == 200 and response.json():
        link_url = response.json()[0]['link']
        if link_url is not None:
            # Download the file into the file_path
            response = requests.get(link_url)
            if response.status_code == 200:
                with open(file_path, 'wb') as file:
                    file.write(response.content)
                return file_path
            else:
                raise Exception(
                    f'Error downloading link: {response.status_code}')
    else:
        raise Exception(
            f'Error getting link information: {response.status_code}')
